Name:		cantata
Version:	3.2.1
Release:	%mkrel 3
Summary:	Graphical client for the Music Player Daemon (MPD)
License:	GPLv2+
Group:		Graphical desktop/KDE
# https://github.com/CDrummond/cantata/
# Cantata is no longer maintained, repo at CDrummond is now archived,
# but new fork appears that also support QT6 (above url)
URL:		https://github.com/nullobsi/cantata
Source0:	https://github.com/nullobsi/cantata/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	cdparanoia
BuildRequires:	media-player-info
BuildRequires:	cdda-devel
BuildRequires:	ebur128-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	qt6-qtmultimedia
BuildRequires:	cmake(Qt6Concurrent)
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6DBus)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6LinguistTools)
BuildRequires:	cmake(Qt6Multimedia)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Sql)
BuildRequires:	cmake(Qt6Svg)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	pkgconfig(avahi-client)
BuildRequires:	pkgconfig(libcddb)
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(libmtp)
BuildRequires:	pkgconfig(libmusicbrainz5)
BuildRequires:	pkgconfig(libvlc)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(taglib) >= 2.0
BuildRequires:	pkgconfig(speexdsp)
BuildRequires:	pkgconfig(udev)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(zlib)

Requires:	qt6-qtmultimedia
Recommends:	media-player-info
Recommends:	mpd

%description
Cantata is a (yet another!) graphical client for the music player daemon (MPD).

Supporting features:
  * Multiple MPD collections.
  * Highly customisable layout.
  * Songs grouped by album in play queue.
  * Context view to show artist, album, and song information of current track.
  * Simple tag editor.
  * File organizer - use tags to organize files and folders.
  * Ability to calculate ReplyGain tags.
  * Dynamic playlists.
  * Online services; Jamendo, Magnatune, SoundCloud, and Podcasts.
  * Radio stream support - with the ability to search for streams via TuneIn,
    ShoutCast, or Dirble.
  * USB-Mass-Storage and MTP device support.
  * Audio CD ripping and playback.
  * Playback of non-MPD songs, via simple in-built HTTP server if connected
    to MPD via a standard socket, otherwise filepath is sent to MPD.
  * MPRISv2 DBUS interface.
  * Support for KDE global shortcuts (KDE builds), GNOME media keys, and
    standard media keys (via Qxt support).
  * Ubuntu/ambiance theme integration.
  * Basic support for touch-style interface (views are made 'flickable').
  * Scrobbling.
  * Ratings support.

%files
%doc AUTHORS ChangeLog README TODO
%license LICENSE
%{_bindir}/%{name}
%{_libexecdir}/Cantata/
%{_datadir}/applications/dog.unix.%{name}.Cantata.desktop
%{_datadir}/Cantata/
%{_iconsdir}/hicolor/*/apps/*%{name}*.*
%{_metainfodir}/dog.unix.%{name}.Cantata.metainfo.xml

#------------------------------------------------------------------------------

%prep
%autosetup -p1

# Hack to fix install path for x86_64 build
# TODO report upstream for a fix -done.
sed -i -e 's|LINUX_LIB_DIR lib|LINUX_LIB_DIR %{_lib}|g' CMakeLists.txt

%build
%cmake_qt6 \
	-DENABLE_HTTP_STREAM_PLAYBACK=ON \
	-DENABLE_REMOTE_DEVICES=ON
%cmake_build

%install
%cmake_install


%changelog
* Sun Dec 08 2024 daviddavid <daviddavid> 3.2.1-3.mga10
+ Revision: 2122600
- rebuild for new ffmpeg 7.1

* Fri Oct 04 2024 daviddavid <daviddavid> 3.2.1-2.mga10
+ Revision: 2103196
- re-enable taglib v2 support

* Fri Oct 04 2024 daviddavid <daviddavid> 3.2.1-1.mga10
+ Revision: 2103077
- new version: 3.2.1 (new maintained fork https://github.com/nullobsi/cantata,
  original project has been archived upstream)
- switch to Qt6

* Wed Mar 16 2022 luigiwalser <luigiwalser> 2.5.0-1.mga9
+ Revision: 1794916
- 2.5.0
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Wed Dec 16 2020 umeabot <umeabot> 2.4.2-2.mga8
+ Revision: 1658186
- Rebuild for new Qt5

* Tue Sep 22 2020 daviddavid <daviddavid> 2.4.2-1.mga8
+ Revision: 1629438
- new version: 2.4.2

* Sun Feb 23 2020 daviddavid <daviddavid> 2.4.1-1.mga8
+ Revision: 1549641
- new version: 2.4.1

* Mon Feb 17 2020 daviddavid <daviddavid> 2.4.0-1.mga8
+ Revision: 1536978
- new version: 2.4.0

* Sat Feb 15 2020 umeabot <umeabot> 2.3.3-3.mga8
+ Revision: 1524414
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sat Mar 30 2019 umeabot <umeabot> 2.3.3-2.mga7
+ Revision: 1381399
- Qt5 Rebuild

* Sun Dec 30 2018 daviddavid <daviddavid> 2.3.3-1.mga7
+ Revision: 1347225
- new version: 2.3.3

* Sat Sep 22 2018 umeabot <umeabot> 2.3.2-2.mga7
+ Revision: 1295971
- Mageia 7 Mass Rebuild

* Fri Aug 03 2018 daviddavid <daviddavid> 2.3.2-1.mga7
+ Revision: 1246981
- new version: 2.3.2

* Tue Jun 19 2018 daviddavid <daviddavid> 2.3.1-2.mga7
+ Revision: 1238107
- disable the D-Bus service to fix CVE-2018-12559, CVE-2018-1256[0-2] (mga#23201)

* Thu Jun 07 2018 daviddavid <daviddavid> 2.3.1-1.mga7
+ Revision: 1235067
- new version: 2.3.1

* Fri Apr 27 2018 daviddavid <daviddavid> 2.3.0-1.mga7
+ Revision: 1222815
- new version: 2.3.0

* Wed Oct 04 2017 daviddavid <daviddavid> 2.2.0-1.mga7
+ Revision: 1168722
- new version: 2.2.0

* Mon Jul 31 2017 daviddavid <daviddavid> 2.1.0-1.mga7
+ Revision: 1132979
- new version: 2.1.0
- rename and rediff libsolid_static patch
- use system ebur128

* Tue May 02 2017 akien <akien> 2.0.1-5.mga6
+ Revision: 1098271
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 2.0.1-4.mga6
+ Revision: 1089844
- Rebuild for ffmpeg 3.2.4

* Thu Jun 23 2016 daviddavid <daviddavid> 2.0.1-3.mga6
+ Revision: 1037354
- but recommends mpd instead

* Wed Jun 22 2016 daviddavid <daviddavid> 2.0.1-2.mga6
+ Revision: 1037174
- do not requires mpd (fixes mga#16678)

* Fri Jun 03 2016 daviddavid <daviddavid> 2.0.1-1.mga6
+ Revision: 1020183
- new version: 2.0.1
- remove merged upstream patch

* Tue Mar 15 2016 daviddavid <daviddavid> 2.0.0-2.mga6
+ Revision: 990890
- compile code with -fPIC (fix build)
  * add patch to fix cmake CXXFLAGS
  * add -DCMAKE_CXX_FLAGS='-fPIC' cmake option
- improve more description

* Tue Jan 26 2016 daviddavid <daviddavid> 2.0.0-1.mga6
+ Revision: 927841
- new version: 2.0.0
- switch build to Qt5
- update URL and Source URL
- improve description and summary

* Sat Oct 24 2015 daviddavid <daviddavid> 1.4.1-10.mga6
+ Revision: 894882
- remove empty lang files to fix build with latest rpm

* Tue Sep 01 2015 cjw <cjw> 1.4.1-9.mga6
+ Revision: 871908
- rebuild with gcc 5

* Thu Jul 02 2015 fwang <fwang> 1.4.1-8.mga6
+ Revision: 849448
- rebuild for libmusicbrainz5

* Fri Nov 14 2014 akien <akien> 1.4.1-7.mga5
+ Revision: 797172
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 1.4.1-6.mga5
+ Revision: 741291
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.4.1-5.mga5
+ Revision: 726011
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.4.1-4.mga5
+ Revision: 678306
- Mageia 5 Mass Rebuild

* Wed Sep 10 2014 fwang <fwang> 1.4.1-3.mga5
+ Revision: 674512
- build solid as static

* Wed Sep 10 2014 fwang <fwang> 1.4.1-2.mga5
+ Revision: 674492
- rebuild

* Sun Aug 31 2014 bersuit <bersuit> 1.4.1-1.mga5
+ Revision: 670078
- Update to new Upstream version 1.4.1
- Update to new Upstream version 1.3.4

* Sat Apr 05 2014 juancho <juancho> 1.3.3-1.mga5
+ Revision: 611789
- Updated to 1.3.3

* Sat Oct 19 2013 umeabot <umeabot> 1.1.2-2.mga4
+ Revision: 533656
- Mageia 4 Mass Rebuild

* Tue Sep 03 2013 fwang <fwang> 1.1.2-1.mga4
+ Revision: 474642
- update installdir for replaygain
- update file list
- new version 1.1.2

* Fri Jul 12 2013 fwang <fwang> 1.0.3-2.mga4
+ Revision: 453256
- fix build with recent ffmpeg
- rebuild for new ffmpeg

* Thu May 30 2013 fwang <fwang> 1.0.3-1.mga4
+ Revision: 433335
- fix desktop file
- update file list
- new version 1.0.3

* Thu Feb 07 2013 juancho <juancho> 0.9.2-1.mga3
+ Revision: 395053
- Updated to 0.9.2 (bugfix release)

* Fri Jan 11 2013 umeabot <umeabot> 0.9.1-3.mga3
+ Revision: 347387
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 0.9.1-2.mga3
+ Revision: 341614
- rebuild for new ffmpeg

* Sat Dec 22 2012 fwang <fwang> 0.9.1-1.mga3
+ Revision: 333798
- new version 0.9.1

* Sat Dec 08 2012 fwang <fwang> 0.9.0-1.mga3
+ Revision: 328018
- update file list
- new version 0.9.0

* Thu Sep 06 2012 fwang <fwang> 0.8.3-1.mga3
+ Revision: 288733
- new version 0.8.3

* Thu Jul 26 2012 fwang <fwang> 0.8.2-1.mga3
+ Revision: 274441
- new version 0.8.2

* Tue Jul 17 2012 fwang <fwang> 0.8.1-2.mga3
+ Revision: 271647
- add more features

* Tue Jul 17 2012 fwang <fwang> 0.8.1-1.mga3
+ Revision: 271642
- new version 0.8.1

* Tue Jun 05 2012 juancho <juancho> 0.7.1-1.mga3
+ Revision: 255949
- Added missing BR taglib-devel
- Updated to 0.7.1

* Thu Feb 02 2012 juancho <juancho> 0.3.0-1.mga2
+ Revision: 204003
- Updated to 0.3.0

* Mon Jan 09 2012 juancho <juancho> 0.2.0-2.mga2
+ Revision: 194223
- Removed now uneeded cmake option

* Mon Jan 09 2012 juancho <juancho> 0.2.0-1.mga2
+ Revision: 193698
- Updated to 0.2.0 - Upload sources
- Updated to 0.2.0

* Fri Jan 06 2012 juancho <juancho> 0.1.2-1.mga2
+ Revision: 192746
- imported package cantata

